let shareButton = null;
let watingdots = ` <svg viewBox="0 0 24 12">
<circle cx="4" cy="3" r="1.5" fill="currentColor"/>
<circle cx="12" cy="3" r="1.5" fill="currentColor"/>
<circle cx="20" cy="3" r="1.5" fill="currentColor"/>
<path fill="none" d="M0 0h24v24H0z"/>
</svg>`;

function createBtn() {
    const button = document.createElement("button");
    button.id = "hs-share-btn";
    button.classList.add("button", "flex", "gap-2", "justify-center", "btn-neutral");
    const styleString = `min-width: 100px;border-radius: 10px;padding: 0.5rem 0.2rem 0.3rem 0.2rem;
    background-color: #fff;box-shadow: 0 3px 4px rgba(0, 0, 0, 0.1);width: 5%; margin: 10px`
    button.setAttribute('style', styleString);
    button.innerHTML = `${shareIconSvg}${shareButtonText}`;
    return button;
}

function appendShareButton() {
    const bottom = document.querySelector('div[data-ignore-for-autoscroll="true"]')
    if (!bottom) return;
    const parent = bottom.firstChild
    if (!parent) return;
    // console.log(parent)
    parent.insertAdjacentHTML('afterbegin', '<div id="share-wrapper"></div>');
    const buttonsWrapper = document.querySelector("#share-wrapper")
    buttonsWrapper.classList.add("flex")
    if (!buttonsWrapper) return;
    buttonsWrapper.appendChild(shareButton);
    const fieldset = document.querySelector('fieldset')
    fieldset.setAttribute("style", "width: 95%")
    buttonsWrapper.appendChild(fieldset)
}

function setBtnStatus(button, status = "init") {
  let icon = "";
  if (status === "init") {
    icon = `${shareIconSvg}${shareButtonText}`;
    button.style.cursor = "pointer";
  } else if (status === "sharing") {
    icon = watingdots;
    button.style.cursor = "initial";
  }
  button.innerHTML = `${icon}`;
}

function getAvatarImage() {
  return new Promise(async (resolve) => {
    try {
      const div = document.querySelector(".flex.items-end.col-start-3.pb-1 > div")
      const username = div.innerText
      // div 不能 drawImage，直接画出来
      const canvas = document.createElement('canvas');
      const ctx = canvas.getContext('2d');
      canvas.width = 30
      canvas.height = 30
      ctx.fillStyle = 'rgb(85, 69, 160)';
      ctx.beginPath();
      ctx.arc(15, 15, 15, 0, 2 * Math.PI);
      ctx.fill();
      ctx.fillStyle = 'white';
      ctx.font = '14px Arial';
      ctx.fontWeight = "700";
      ctx.textAlign = 'center';
      ctx.textBaseline = 'middle'; 
      ctx.fillText(username, 15, 15); 

      const base64 = canvas.toDataURL("image/png");
      // console.log(base64)
      resolve(base64);
    } catch (error) {
      console.log("Error generating avatar image.");
      resolve("");
    }
  });
}

async function shareSession() {
  // console.log('click')
  try {
    if (isRequesting) return;
    isRequesting = true;
    
    setBtnStatus(shareButton, "sharing");

    const threadContainer = document.querySelectorAll(".ReactMarkdown > .contents");

    const avatarUrl = await getAvatarImage();
    const title = document.querySelector('button[data-testid="chat-menu-trigger"]').innerText
    let conversationData = {
      title: title,
      avatarUrl: avatarUrl,
      items: [],
      model: "Claude",
    };
    
    for (let i = 0; i <  threadContainer.length; i++) {
      const el = threadContainer[i];
      // console.log(el)
      if (isEven(i)) {
        conversationData.items.push({
          from: "human",
          value: el.innerText,
        });
      } else {
        conversationData.items.push({
          from: "claude",
          value: el.outerHTML,
        });
      }
    }
    // console.log(conversationData)

    await postConversationData(conversationData, "claude");
    setBtnStatus(shareButton, "init");
} catch (error) {
    setBtnStatus(shareButton, "init");
    isRequesting = false;
  }
}

function init() {
  console.log("claude init")
  shareButton = createBtn();
  const timer = setInterval(() => {
      const shareBtn = document.querySelector("#hs-share-btn");
      if (!shareBtn || shareBtn.style.display === "none") {
        appendShareButton();
        // console.log('add button')
      }
  }, 2000);
  shareButton.addEventListener("click", shareSession);
}

if (
  document.readyState === "complete" ||
  document.readyState === "interactive"
  ) {
  init();
  } else {
  document.addEventListener("DOMContentLoaded", init);
}