let shareButton = null;
function getAvatarImage() {
  const image = document.querySelectorAll("img")[0];
  return renderImage(image);
}

function createBtn() {
  const btn = document.createElement("div");

  btn.classList.add("home_window-action-button__Is6GK");
  btn.classList.add("window-action-button"); // 
  setBtnStatus(btn);

  return btn;
}

function setBtnStatus(button, status = "init") {
  let icon = "";
  if (status === "init") {
    icon = shareIconSvg;
    button.style.cursor = "pointer";
  } else if (status === "sharing") {
    icon = ThreeDots;
    button.style.cursor = "initial";
  }

  button.innerHTML = `<div class="button_icon-button__BC_Ca button_border__nGPHl undefined  clickable" title="分享 Prompt" role="button">
      <div class="button_icon-button-icon__qlUH3 undefined">
        ${icon}
      </div></div>`;
}

// 处理部分浏览器（如Edge）的代码<code>是不带样式的
function transformHTMLFromChatGPTNext(html) {
  if (html.match(/<code\s+class=/) === null && html.indexOf("</code>") !== -1) {
    // 含有<code>节点且不含class属性的情况
    // 当<code>标签的内容只有一行时不用处理，当<code>标签的内容有跨行时才需要插入class="!whitespace-pre hljs"属性
    const newHtml = html.replace(
      /<code([\s\S]*?)>((?:.|\n)*?)<\/code>/gm,
      (match, attributes, content) => {
        if (/\n/.test(content)) {
          return `<code${attributes} class="!whitespace-pre hljs">${content}</code>`;
        } else {
          return match;
        }
      }
    );
    return newHtml;
  } else {
    return html;
  }
}

function getSetConfig() {
  let data = JSON.parse(localStorage.getItem("chat-next-web-store") || "{}");
  return data?.state?.config || {};
}

function appendShareButton() {
  const buttonsWrapper =
    document.querySelector('[class^="home_window-actions__"]') ||
    document.querySelector('[class^="window-actions"]'); //
  if (!buttonsWrapper) return;
  buttonsWrapper.appendChild(shareButton);
}

function createObserver(retry = true) {
  const target = document.querySelector(".home_window-content__RRVow");

  if (target) {
    appendShareButton();
    const observer = new MutationObserver(function (mutations_list) {
      mutations_list.forEach(function (mutation) {
        if (mutation.addedNodes.length > 0) {
          appendShareButton();
        }
      });
    });

    observer.observe(document.querySelector(".home_window-content__RRVow"), {
      subtree: false,
      childList: true,
    });
  } else {
    if (retry) {
      setTimeout(() => createObserver(false), 1000);
    }
  }
}

async function shareSession() {
  try {
    if (isRequesting) return;
    isRequesting = true;
    setBtnStatus(shareButton, "sharing");

    const threadContainer = document.getElementsByClassName("home_chat-body__mbaM8")[0];
    const avatarUrl = await getAvatarImage();
    const config = getSetConfig();
    let conversationData = {
      avatarUrl,
      model: config?.modelConfig?.model || "",
      items: [],
    };

    for (const node of threadContainer.children) {
      const markdown = node.querySelector(".markdown-body");
      if (![...node.classList].includes("home_chat-message__rdH_g")) {
        conversationData.items.push({
          from: "human",
          value: markdown.innerText,
        });
      } else {
        conversationData.items.push({
          from: "gpt",
          value: transformHTMLFromChatGPTNext(markdown.outerHTML),
        });
      }
    }

    // 如果第一条是GPT的，则过滤掉
    if (conversationData.items[0].from === "gpt") {
      conversationData.items.shift();
    }

    await postConversationData(conversationData, "gpt");
    setBtnStatus(shareButton, "init");
  } catch (error) {
    setBtnStatus(shareButton, "init");
    isRequesting = false;
  }
}

function init() {
  console.log("edu.js");
  shareButton = createBtn();
  createObserver();
  shareButton.addEventListener("click", shareSession);
}

window.onload = function () {
  try {
    init();
  } catch (error) {
    console.warn(error);
  }
};
