let shareButton = null;
function getAvatarImage() {
  return new Promise(async (resolve) => {
    try {
      const canvas = document.createElement("canvas");
      const image = document.querySelectorAll("img")[1];
      canvas.width = 30;
      canvas.height = 30;
      canvas.getContext("2d").drawImage(image, 0, 0);
      const base64 = canvas.toDataURL("image/jpeg");
      resolve(base64);
    } catch (error) {
      console.log("Error generating avatar image.");
      resolve("");
    }
  });
}

function createBtn() {
  // 创建一个新的按钮元素
  const button = document.createElement("button");
    // 设置按钮的属性
  button.id = "hs-share-btn";
  button.classList.add("btn", "flex", "gap-2", "justify-center", "btn-neutral");
  button.setAttribute('style', 'max-width: 120px;');
  button.innerHTML = `${shareIconSvg}${shareButtonText}`;

  return button;
}

function appendShareButton() {
  let buttonsWrapper;
  const WrapperSelector = "#__next main form > div div:nth-of-type(1)";
  // if (window.location.pathname === '/') {
  //   buttonsWrapper =
  //   document.querySelector("#__next main form > div")
  // } else {
  //   buttonsWrapper =
  //   document.querySelector(WrapperSelector + " > div") ||
  //   document.querySelector(WrapperSelector);
  // }
  buttonsWrapper =
    document.querySelector(WrapperSelector + " > div") ||
    document.querySelector(WrapperSelector);
   // 如果没有找到元素,输出并直接返回
  if (!buttonsWrapper) {
    console.log("no WrapperSelector");
    return;
  }
  const firstElement = buttonsWrapper ? buttonsWrapper.firstChild : null;
  // 修复分享按钮节点顺序前后不一致问题：会话前后均放在第一位置。存在元素放在第一元素之前，不然就放在末尾。
  if (firstElement) {
    buttonsWrapper.insertBefore(shareButton, firstElement);
  } else {
    buttonsWrapper.appendChild(shareButton);
  }
}
// 函数：分享会话数据
async function shareSession() {
  if (isRequesting) return;

  isRequesting = true;

  const threadContainer = document.getElementsByClassName(
    "flex flex-col text-sm dark:bg-gray-800"
  )[0];

  const gptVersionTag = document.querySelector('a.underline');

  let model;

  const chatGptPlusElement = document.querySelector(".gold-new-button");
  const isNotChatGptPlus =
    chatGptPlusElement && chatGptPlusElement.innerText.includes("Upgrade");

  if (!isNotChatGptPlus) {
    const modelElement = threadContainer.firstChild;
    model = modelElement.innerText;
  }
  const avatarUrl = await getAvatarImage();
  const conversationData = {
    // GPT 以生成好的对话标题作为 title，可直接使用
    title: document.title,
    version: gptVersionTag ? gptVersionTag.innerHTML : '',
    avatarUrl: avatarUrl,
    model,
    items: [],  
  };
 // 循环所有的消息节点，提取消息内容
  for (const node of threadContainer.children) {
    const markdown = node.querySelector(".markdown");
    if ([...node.classList].includes("dark:bg-gray-800")) {
      const warning = node.querySelector(".text-orange-500");
      if (warning) {
        conversationData.items.push({
          from: "human",
          value: warning.innerText.split("\n")[0],
        });
      } else {
        const reg = /\d\s\/\s\d/;
        const text = node.textContent.replace(reg, "");
        conversationData.items.push({
          from: "human",
          value: text,
        });
      }
    } else if (markdown) {
      conversationData.items.push({
        from: "gpt",
        value: markdown.outerHTML,
      });
    }
  }



  shareButton.textContent = sharingText;
  shareButton.style.cursor = "initial";

  await postConversationData(conversationData, "gpt");

  setTimeout(() => {
    shareButton.innerHTML = `<svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-3 h-3">
        <path stroke-linecap="round" stroke-linejoin="round" d="M7.217 10.907a2.25 2.25 0 100 2.186m0-2.186c.18.324.283.696.283 1.093s-.103.77-.283 1.093m0-2.186l9.566-5.314m-9.566 7.5l9.566 5.314m0 0a2.25 2.25 0 103.935 2.186 2.25 2.25 0 00-3.935-2.186zm0-12.814a2.25 2.25 0 103.933-2.185 2.25 2.25 0 00-3.933 2.185z" />
      </svg>${shareButtonText}`;
    shareButton.style.cursor = "pointer"; // 按钮光标样式设置为“pointer”，即手形
    isRequesting = false;
  }, 1000);
}
// 函数：初始化脚本
function init() {
  console.log("openai init");// 在控制台输出初始化信息
  shareButton = createBtn();// 创建分享按钮

  appendShareButton(); // 在页面上添加分享按钮
  // 每隔2秒检查一次分享按钮是否存在或是否被隐藏，如果是则重新添加

  const timer = setInterval(() => {
    const shareBtn = document.querySelector("#hs-hs-share-btn");
    if (!shareBtn || shareBtn.style.display === "none") {
      appendShareButton();
    }
  }, 2000);
  // 当分享按钮被点击时，执行 shareSession 函数
  shareButton.addEventListener("click", shareSession);
}
// 如果文档已经加载完成或者文档是交互状态，执行 init 函数
if (
  document.readyState === "complete" ||
  document.readyState === "interactive"
) {
  init();
} else {
  document.addEventListener("DOMContentLoaded", init);
}
